@@ -2,6 +2,8 @@ __all__ = (
     'get_client',
 )
 
+from urllib.parse import urlparse
+
 import pytz
 from django.utils.functional import LazyObject
 from requests import Session
@@ -11,8 +13,14 @@ from zeep import Client
 from zeep.cache import SqliteCache
 from zeep.transports import Transport
 
-TZ_AR = pytz.timezone(pytz.country_timezones["ar"][0])
-CIPHERS = DEFAULT_CIPHERS + "HIGH:!DH:!aNULL"
+TZ_AR = pytz.timezone(pytz.country_timezones['ar'][0])
+CIPHERS = DEFAULT_CIPHERS + 'HIGH:!DH:!aNULL'
+WSDLS = {
+    ('wsaa', False): 'https://wsaa.afip.gov.ar/ws/services/LoginCms?wsdl',
+    ('wsfe', False): 'https://servicios1.afip.gov.ar/wsfev1/service.asmx?WSDL',
+    ('wsaa', True): 'https://wsaahomo.afip.gov.ar/ws/services/LoginCms?wsdl',
+    ('wsfe', True): 'https://wswhomo.afip.gov.ar/wsfev1/service.asmx?WSDL',
+}
 
 
 class AFIPAdapter(HTTPAdapter):
@@ -20,12 +28,12 @@ class AFIPAdapter(HTTPAdapter):
 
     def init_poolmanager(self, *args, **kwargs):
         context = create_urllib3_context(ciphers=CIPHERS)
-        kwargs["ssl_context"] = context
+        kwargs['ssl_context'] = context
         return super().init_poolmanager(*args, **kwargs)
 
     def proxy_manager_for(self, *args, **kwargs):
         context = create_urllib3_context(ciphers=CIPHERS)
-        kwargs["ssl_context"] = context
+        kwargs['ssl_context'] = context
         return super().proxy_manager_for(*args, **kwargs)
 
 
@@ -33,50 +41,52 @@ class LazyTransport(LazyObject):
     """A lazy-initialized Zeep transport.
 
     This transport does two non-default things:
-    - Reduces TLS security. Sadly, AFIP only has insecure endpoints, so we're forced to
-      reduce security to talk to them.
+    - Reduces TLS security. Sadly, AFIP only has insecure endpoints, so we're
+      forced to reduce security to talk to them.
     - Cache the WSDL file for a whole day.
     """
 
     def _setup(self):
         """Initialise this lazy object with a celery app instance."""
         session = Session()
-        session.mount("https://servicios1.afip.gov.ar", AFIPAdapter())
 
-        self._wrapped = Transport(cache=SqliteCache(timeout=86400), session=session)
+        # For each WSDL, extract the domain, and add it as an exception:
+        for url in WSDLS.values():
+            parsed = urlparse(url)
+            base_url = f'{parsed.scheme}://{parsed.netloc}'
+            session.mount(base_url, AFIPAdapter())
+
+        self._wrapped = Transport(
+            cache=SqliteCache(timeout=86400),
+            session=session,
+        )
 
 
 transport = LazyTransport()
-wsdls = {
-    ('wsaa', False): 'https://wsaa.afip.gov.ar/ws/services/LoginCms?wsdl',
-    ('wsfe', False): 'https://servicios1.afip.gov.ar/wsfev1/service.asmx?WSDL',
-    ('wsaa', True): 'https://wsaahomo.afip.gov.ar/ws/services/LoginCms?wsdl',
-    ('wsfe', True): 'https://wswhomo.afip.gov.ar/wsfev1/service.asmx?WSDL',
-}
-
 cached_clients = {}
 
 
 def get_client(service_name, sandbox=False):
     """
-    Returns a client for a given service.
+    Return a client for a given service.
 
     The `sandbox` argument should only be necessary if a the client will be
     used to make a request. If it will only be used to serialize objects, it is
-    irrelevant.  Avoid the overhead of determining the sandbox mode in the
-    calling context if only serialization operations will take place.
+    irrelevant. A caller can avoid the overhead of determining the sandbox
+    mode in the calling context if only serialization operations will take
+    place.
 
     :param string service_name: The name of the web services.
     :param bool sandbox: Whether the sandbox (or production) environment should
         be used by the returned client.
-    :returns: A zeep client to communicate with an AFIP webservice.
+    :returns: A zeep client to communicate with an AFIP web service.
     :rtype: zeep.Client
     """
     key = (service_name.lower(), sandbox,)
 
     try:
         if key not in cached_clients:
-            cached_clients[key] = Client(wsdls[key], transport=transport)
+            cached_clients[key] = Client(WSDLS[key], transport=transport)
 
         return cached_clients[key]
     except KeyError:
