@@ -8,7 +8,7 @@ from django_afip.clients import get_client
 class TestGetService(TestCase):
     def test_services_are_cached(self):
         service1 = get_client('wsfe', False)
-        with patch.dict('django_afip.clients.wsdls', values={}, clear=True):
+        with patch.dict('django_afip.clients.WSDLS', values={}, clear=True):
             service2 = get_client('wsfe', False)
 
         self.assertEqual(service1, service2)
